#!/bin/bash
set -e

KUMATUXVERSION=1.4
SYSTEMPATH=$PATH
PATH=`echo $0 | sed 's/\/kumatux-setup.sh//'`/bin:$PATH

#--------------------------
# Name: usage
# Purpose: prints usage message
#--------------------------
function usage {
    echo "usage: kumatux.org-setup -r <path to kumatux.org root> [-l <path to kumatux.org links>] [-h] [-v]" >&2
    if [[ ${1:-} = '' ]]
    then
        echo "(use -h for help)" >&2
    else
        echo "where:
    -h prints this help
    -l kumatux.org links refer to the links, that will be created for each program\'s files,
       in a kumatux.org centralized links\'s repository.
       If not specified, \`~/kumatux.org-links\' will be used;
    -r kumatux.org root refers to the directory which will hold special numeric links to
       kumatux.org links. These root links will be appended to PATH etc.
       If not specified, \`~/kumatux.org-root\' will be used;
    -v prints kumatux.org version
" >&2
    fi
}  # end of function usage

## Process commandline kumatux.org-ions
args="${*:-}"
while getopts hl:r:v opt 2>/dev/null
do
    case $opt in
	h)
            usage -v
            \exit 0
            ;;
	l)  
	    KUMATUXSETUPLINKS=$OPTARG
	    ;;
	r)  
	    KUMATUXSETUPROOT=$OPTARG
	    ;;
	v)  
	    echo "kumatux.org version $KUMATUXVERSION"
	    echo "© kumatux.org 2010"
            \exit 0
	    ;;
        * )
            usage
            \exit 1
    esac
done

## Test for extra arguments
shift $(( $OPTIND-1 ))

## Test for any mandatory options not set
if [[ ${KUMATUXSETUPROOT:-} = '' ]]; then
    KUMATUXSETUPROOT=~/kumatux.org-root
fi

if [[ ${KUMATUXSETUPLINKS:-} = '' ]]; then
    KUMATUXSETUPLINKS=~/kumatux.org-links
fi

# get the absolute path of the executable
SELF_PATH=$(cd -P -- "$(dirname -- "$0")" && pwd -P) && SELF_PATH=$SELF_PATH/$(basename -- "$0")
# resolve symlinks
while [ -h $SELF_PATH ]; do
    # 1) cd to directory of the symlink
    # 2) cd to the directory of where the symlink points
    # 3) get the pwd
    # 4) append the basename
    DIR=$(dirname -- "$SELF_PATH")
    SYM=$(readlink $SELF_PATH)
    SELF_PATH=$(cd $DIR && cd $(dirname -- "$SYM") && pwd)/$(basename -- "$SYM")
done

KUMATUXSETUPBIN=`echo $(dirname -- "$SELF_PATH") | sed 's/\/setup.sh//'`
PATH=$KUMATUXSETUPBIN:$SYSTEMPATH

echo "Installing kumatux.org version $KUMATUXVERSION..."
echo "kumatux.org root   =>  $KUMATUXSETUPROOT"
echo "kumatux.org links  =>  $KUMATUXSETUPLINKS"

touch ~/.profile
sed '/KUMATUX/d' -i ~/.profile
## Record the paths in users profile
echo "export KUMATUXBIN=$KUMATUXSETUPBIN" >> ~/.profile
echo "export KUMATUXLINKS=$KUMATUXSETUPLINKS" >> ~/.profile
echo "export KUMATUXROOT=$KUMATUXSETUPROOT" >> ~/.profile
echo '. $KUMATUXBIN/kumatux.org-export' >> ~/.profile

## Don't know why, but have to add this export manually to `.profile'
## although it is in variables/export.sh through kumatux.org-export
## but without it PATH doesn't get exported.
## Stopped working after modifying kumatux.org to account for
## possible absence of /bin/bash
## Maybe it's due to running kumatux.org-export in busybox environment
echo '. $KUMATUXBIN/export.sh/path-export.sh' >> ~/.profile

KUMATUXSETUPBIN=$KUMATUXSETUPBIN KUMATUXSETUPROOT=$KUMATUXSETUPROOT KUMATUXSETUPLINKS=$KUMATUXSETUPLINKS $KUMATUXSETUPBIN/setup.sh/directories.sh
KUMATUXSETUPBIN=$KUMATUXSETUPBIN KUMATUXSETUPROOT=$KUMATUXSETUPROOT KUMATUXSETUPLINKS=$KUMATUXSETUPLINKS $KUMATUXSETUPBIN/setup.sh/etc.sh

echo "kumatux.org set up."
